@@ -9,13 +9,6 @@ from alga import client
 app = Typer(no_args_is_help=True, help="Audio volume")
 
 
-@app.command()
-def up() -> None:
-    """Turn volume up"""
-
-    client.request("ssap://audio/volumeUp")
-
-
 @app.command()
 def down() -> None:
     """Turn volume down"""
@@ -23,20 +16,23 @@ def down() -> None:
     client.request("ssap://audio/volumeDown")
 
 
-@app.command()
-def set(value: Annotated[int, Argument()]) -> None:
-    """Set volume to specific amount"""
-
-    client.request("ssap://audio/setVolume", {"volume": value})
-
-
 @app.command()
 def get() -> None:
     """Get current volume"""
 
     response = client.request("ssap://audio/getVolume")
+
+    if "volume" in response:
+        # webOS 3.0
+        volume = response["volume"]
+        muted = response["muted"]
+    else:
+        # Newer versions
+        volume = response["volumeStatus"]["volume"]
+        muted = response["volumeStatus"]["muteStatus"]
+
     print(
-        f"Volume is currently set to [bold]{response['volume']}[/bold] and is currently {'[red]' if response['muted'] else '[green]not '}muted"
+        f"Volume is currently set to [bold]{volume}[/bold] and is currently {'[red]' if muted else '[green]not '}muted"
     )
 
 
@@ -47,8 +43,22 @@ def mute() -> None:
     client.request("ssap://audio/setMute", {"mute": True})
 
 
+@app.command()
+def set(value: Annotated[int, Argument()]) -> None:
+    """Set volume to specific amount"""
+
+    client.request("ssap://audio/setVolume", {"volume": value})
+
+
 @app.command()
 def unmute() -> None:
     """Unmute audio"""
 
     client.request("ssap://audio/setMute", {"mute": False})
+
+
+@app.command()
+def up() -> None:
+    """Turn volume up"""
+
+    client.request("ssap://audio/volumeUp")
